@@ -3,10 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2008';
+our $VERSION = '0.2009';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
-use MIDI::Util qw(dura_size);
+use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util);
+use MIDI::Util qw(dura_size set_time_signature);
 use Music::Duration;
 
 use Moo;
@@ -384,12 +385,7 @@ sub set_time_sig {
     my ($beats, $divisions) = split /\//, $self->signature;
     $self->beats($beats);
     $self->divisions($divisions);
-    $self->score->time_signature(
-        $self->beats,
-        ( $self->divisions == 8 ? 3 : 2),
-        ( $self->divisions == 8 ? 24 : 18 ),
-        8
-    );
+    set_time_signature($self->score, $self->signature);
 }
 
 
@@ -468,7 +464,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2008
+version 0.2009
 
 =head1 SYNOPSIS
 
